# Aliyun Qwen

Рекомендуется использовать модель `qwen-plus-latest`.

Пример конфигурации:

- Сервис перевода: `qwen-plus-latest`  
- Базовый URL: оставить по умолчанию  
- API ключ: ваш API ключ  
- Таймаут (секунды): 500  
- Температура: 0.0  
- Отправлять температуру: Да  
- Включить JSON режим: Да

Для ограничения скорости используйте Пользовательский режим:
- QPS: 30 или 40
- Pool Max Workers: 1000

<div align="right"> 
<h6><small>Часть содержимого этой страницы была переведена GPT и может содержать ошибки.</small></h6>